Crate zng_wgt_stack
source ·Expand description
Stack widgets, properties and nodes.
Crate
This crate is part of the zng project.
Cargo Features
This crate provides 2 feature flags, 1 enabled by default.
"debug_default"
Enables the "dyn_closure" in debug builds.
Enabled by default.
"dyn_closure"
Box closures at opportune places, such as Var::map, reducing the number of monomorphised types.
This speeds-up compilation time at the cost of runtime.
Structs
WStack layout.- Defines a placement point in the previous item and the origin point of the next.
Traits
- Extension methods for
WidgetInfothat may represent aStack!instance.
Functions
cStack items.cItems alignment.cStack direction.PGet the child index in the parent stack.PGet the child index and number of children.PGet the child index, starting from the last child at0.PIf the child index is even.PIf the child is the first.PIf the child is the last.PIf the child index is odd.- Create a node that estimates the size of stack panel children.
- Create a node that estimates the size of stack panel children.
- Stack node.
cSpace in-between items.- Basic z-stack node.
- Basic z-stack node sized by one of the items.